@@ -60,12 +60,13 @@ The following resources are plain bytes::
     Resource.LIGHTROOM_WORKFLOW: 8000
 """
 from __future__ import absolute_import, unicode_literals
-import attr
-import logging
-import io
 
-from psd_tools.version import __version__
-from psd_tools.constants import Resource, PrintScaleStyle
+import io
+import logging
+
+import attr
+
+from psd_tools.constants import PrintScaleStyle, Resource
 from psd_tools.psd.base import (
     BaseElement,
     ByteElement,
@@ -80,32 +81,44 @@ from psd_tools.psd.base import (
 from psd_tools.psd.color import Color
 from psd_tools.psd.descriptor import DescriptorBlock
 from psd_tools.utils import (
-    read_fmt, write_fmt, read_pascal_string, write_pascal_string,
-    read_length_block, write_length_block, write_bytes, new_registry,
-    read_unicode_string, write_unicode_string, is_readable, trimmed_repr
+    is_readable,
+    new_registry,
+    read_fmt,
+    read_length_block,
+    read_pascal_string,
+    read_unicode_string,
+    trimmed_repr,
+    write_bytes,
+    write_fmt,
+    write_length_block,
+    write_pascal_string,
+    write_unicode_string,
 )
 from psd_tools.validators import in_
+from psd_tools.version import __version__
 
 logger = logging.getLogger(__name__)
 
 TYPES, register = new_registry()
 
-TYPES.update({
-    Resource.BACKGROUND_COLOR: Color,
-    Resource.LAYER_COMPS: DescriptorBlock,
-    Resource.MEASUREMENT_SCALE: DescriptorBlock,
-    Resource.SHEET_DISCLOSURE: DescriptorBlock,
-    Resource.TIMELINE_INFO: DescriptorBlock,
-    Resource.ONION_SKINS: DescriptorBlock,
-    Resource.COUNT_INFO: DescriptorBlock,
-    Resource.PRINT_INFO_CS5: DescriptorBlock,
-    Resource.PRINT_STYLE: DescriptorBlock,
-    Resource.PATH_SELECTION_STATE: DescriptorBlock,
-    Resource.ORIGIN_PATH_INFO: DescriptorBlock,
-    Resource.AUTO_SAVE_FILE_PATH: StringElement,
-    Resource.AUTO_SAVE_FORMAT: StringElement,
-    Resource.WORKFLOW_URL: StringElement,
-})
+TYPES.update(
+    {
+        Resource.BACKGROUND_COLOR: Color,
+        Resource.LAYER_COMPS: DescriptorBlock,
+        Resource.MEASUREMENT_SCALE: DescriptorBlock,
+        Resource.SHEET_DISCLOSURE: DescriptorBlock,
+        Resource.TIMELINE_INFO: DescriptorBlock,
+        Resource.ONION_SKINS: DescriptorBlock,
+        Resource.COUNT_INFO: DescriptorBlock,
+        Resource.PRINT_INFO_CS5: DescriptorBlock,
+        Resource.PRINT_STYLE: DescriptorBlock,
+        Resource.PATH_SELECTION_STATE: DescriptorBlock,
+        Resource.ORIGIN_PATH_INFO: DescriptorBlock,
+        Resource.AUTO_SAVE_FILE_PATH: StringElement,
+        Resource.AUTO_SAVE_FORMAT: StringElement,
+        Resource.WORKFLOW_URL: StringElement,
+    }
+)
 
 
 @attr.s(repr=False, slots=True)
@@ -139,24 +152,26 @@ class ImageResources(DictElement):
 
         :return: ImageResources
         """
-        return cls([
-            (
-                Resource.VERSION_INFO,
-                ImageResource(
-                    key=Resource.VERSION_INFO,
-                    data=VersionInfo(
-                        has_composite=True,
-                        writer='psd-tools %s' % __version__,
-                        reader='psd-tools %s' % __version__,
-                    )
-                )
-            ),
-        ])
+        return cls(
+            [
+                (
+                    Resource.VERSION_INFO,
+                    ImageResource(
+                        key=Resource.VERSION_INFO,
+                        data=VersionInfo(
+                            has_composite=True,
+                            writer="psd-tools %s" % __version__,
+                            reader="psd-tools %s" % __version__,
+                        ),
+                    ),
+                ),
+            ]
+        )
 
     @classmethod
-    def read(cls, fp, encoding='macroman'):
+    def read(cls, fp, encoding="macroman"):
         data = read_length_block(fp)
-        logger.debug('reading image resources, len=%d' % (len(data)))
+        logger.debug("reading image resources, len=%d" % (len(data)))
         with io.BytesIO(data) as f:
             return cls._read_body(f, encoding=encoding)
 
@@ -168,39 +183,39 @@ class ImageResources(DictElement):
             items.append((item.key, item))
         return cls(items)
 
-    def write(self, fp, encoding='macroman'):
+    def write(self, fp, encoding="macroman"):
         def writer(f):
             written = sum(self[key].write(f, encoding) for key in self)
-            logger.debug('writing image resources, len=%d' % (written))
+            logger.debug("writing image resources, len=%d" % (written))
             return written
 
         return write_length_block(fp, writer)
 
     @classmethod
     def _key_converter(self, key):
-        return getattr(key, 'value', key)
+        return getattr(key, "value", key)
 
     def _repr_pretty_(self, p, cycle):
         if cycle:
-            return '{{...}'
+            return "{{...}"
 
-        with p.group(2, '{', '}'):
-            p.breakable('')
+        with p.group(2, "{", "}"):
+            p.breakable("")
             for idx, key in enumerate(self._items):
                 if idx:
-                    p.text(',')
+                    p.text(",")
                     p.breakable()
                 value = self._items[key]
                 try:
                     p.text(Resource(key).name)
                 except ValueError:
                     p.pretty(key)
-                p.text(': ')
+                p.text(": ")
                 if isinstance(value.data, bytes):
                     p.text(trimmed_repr(value.data))
                 else:
                     p.pretty(value.data)
-            p.breakable('')
+            p.breakable("")
 
 
 @attr.s(repr=False, slots=True)
@@ -222,28 +237,29 @@ class ImageResource(BaseElement):
 
         The resource data.
     """
+
     signature = attr.ib(
-        default=b'8BIM',
+        default=b"8BIM",
         type=bytes,
         repr=False,
-        validator=in_({b'8BIM', b'MeSa', b'AgHg', b'PHUT', b'DCSR'})
+        validator=in_({b"8BIM", b"MeSa", b"AgHg", b"PHUT", b"DCSR"}),
     )
     key = attr.ib(default=1000, type=int)
-    name = attr.ib(default='', type=str)
-    data = attr.ib(default=b'', type=bytes, repr=False)
+    name = attr.ib(default="", type=str)
+    data = attr.ib(default=b"", type=bytes, repr=False)
 
     @classmethod
-    def read(cls, fp, encoding='macroman'):
-        signature, key = read_fmt('4sH', fp)
+    def read(cls, fp, encoding="macroman"):
+        signature, key = read_fmt("4sH", fp)
         try:
             key = Resource(key)
         except ValueError:
             if Resource.is_path_info(key):
-                logger.debug('Undefined PATH_INFO found: %d' % (key))
+                logger.debug("Undefined PATH_INFO found: %d" % (key))
             elif Resource.is_plugin_resource(key):
-                logger.debug('Undefined PLUGIN_RESOURCE found: %d' % (key))
+                logger.debug("Undefined PLUGIN_RESOURCE found: %d" % (key))
             else:
-                logger.warning('Unknown image resource %d' % (key))
+                logger.warning("Unknown image resource %d" % (key))
         name = read_pascal_string(fp, encoding, padding=2)
         raw_data = read_length_block(fp, padding=2)
         if key in TYPES:
@@ -260,14 +276,14 @@ class ImageResource(BaseElement):
             data = raw_data
         return cls(signature, key, name, data)
 
-    def write(self, fp, encoding='macroman'):
+    def write(self, fp, encoding="macroman"):
         written = write_fmt(
-            fp, '4sH', self.signature, getattr(self.key, 'value', self.key)
+            fp, "4sH", self.signature, getattr(self.key, "value", self.key)
         )
         written += write_pascal_string(fp, self.name, encoding, 2)
 
         def writer(f):
-            if hasattr(self.data, 'write'):
+            if hasattr(self.data, "write"):
                 return self.data.write(f, padding=1)
             return write_bytes(f, self.data)
 
@@ -285,11 +301,11 @@ class AlphaIdentifiers(ListElement):
     def read(cls, fp, **kwargs):
         items = []
         while is_readable(fp, 4):
-            items.append(read_fmt('I', fp)[0])
+            items.append(read_fmt("I", fp)[0])
         return cls(items)
 
     def write(self, fp, **kwargs):
-        return sum(write_fmt(fp, 'I', item) for item in self)
+        return sum(write_fmt(fp, "I", item) for item in self)
 
 
 @register(Resource.ALPHA_NAMES_PASCAL)
@@ -302,7 +318,7 @@ class AlphaNamesPascal(ListElement):
     def read(cls, fp, **kwargs):
         items = []
         while is_readable(fp):
-            items.append(read_pascal_string(fp, 'macroman', padding=1))
+            items.append(read_pascal_string(fp, "macroman", padding=1))
         return cls(items)
 
     def write(self, fp, **kwargs):
@@ -337,10 +353,10 @@ class Byte(ByteElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        return cls(*read_fmt('B', fp))
+        return cls(*read_fmt("B", fp))
 
     def write(self, fp, **kwargs):
-        return write_fmt(fp, 'B', self.value)
+        return write_fmt(fp, "B", self.value)
 
 
 @register(Resource.GRID_AND_GUIDES_INFO)
@@ -351,6 +367,7 @@ class GridGuidesInfo(BaseElement):
 
     .. py:attribute: version
     """
+
     version = attr.ib(default=1, type=int)
     horizontal = attr.ib(default=0, type=int)
     vertical = attr.ib(default=0, type=int)
@@ -358,18 +375,17 @@ class GridGuidesInfo(BaseElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        version, horizontal, vertical, count = read_fmt('4I', fp)
+        version, horizontal, vertical, count = read_fmt("4I", fp)
         items = []
         for _ in range(count):
-            items.append(read_fmt('IB', fp))
+            items.append(read_fmt("IB", fp))
         return cls(version, horizontal, vertical, items)
 
     def write(self, fp, **kwargs):
         written = write_fmt(
-            fp, '4I', self.version, self.horizontal, self.vertical,
-            len(self.data)
+            fp, "4I", self.version, self.horizontal, self.vertical, len(self.data)
         )
-        written += sum(write_fmt(fp, 'IB', *item) for item in self.data)
+        written += sum(write_fmt(fp, "IB", *item) for item in self.data)
         return written
 
 
@@ -404,6 +420,7 @@ class HalftoneScreen(BaseElement):
     .. py:attribute:: use_accurate
     .. py:attribute:: use_printer
     """
+
     freq = attr.ib(default=0, type=int)
     unit = attr.ib(default=0, type=int)
     angle = attr.ib(default=0, type=int)
@@ -413,18 +430,18 @@ class HalftoneScreen(BaseElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        freq = float(read_fmt('I', fp)[0]) / 0x10000
-        unit = read_fmt('H', fp)[0]
-        angle = float(read_fmt('i', fp)[0]) / 0x10000
-        shape, use_accurate, use_printer = read_fmt('H4x2?', fp)
+        freq = float(read_fmt("I", fp)[0]) / 0x10000
+        unit = read_fmt("H", fp)[0]
+        angle = float(read_fmt("i", fp)[0]) / 0x10000
+        shape, use_accurate, use_printer = read_fmt("H4x2?", fp)
         return cls(freq, unit, angle, shape, use_accurate, use_printer)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, 'I', int(self.freq * 0x10000))
-        written += write_fmt(fp, 'H', self.unit)
-        written += write_fmt(fp, 'i', int(self.angle * 0x10000))
+        written = write_fmt(fp, "I", int(self.freq * 0x10000))
+        written += write_fmt(fp, "H", self.unit)
+        written += write_fmt(fp, "i", int(self.angle * 0x10000))
         written += write_fmt(
-            fp, 'H4x2?', self.shape, self.use_accurate, self.use_printer
+            fp, "H4x2?", self.shape, self.use_accurate, self.use_printer
         )
         return written
 
@@ -439,10 +456,10 @@ class Integer(IntegerElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        return cls(*read_fmt('i', fp))
+        return cls(*read_fmt("i", fp))
 
     def write(self, fp, **kwargs):
-        return write_fmt(fp, 'i', self.value)
+        return write_fmt(fp, "i", self.value)
 
 
 @register(Resource.LAYER_GROUPS_ENABLED_ID)
@@ -455,11 +472,11 @@ class LayerGroupEnabledIDs(ListElement):
     def read(cls, fp, **kwargs):
         items = []
         while is_readable(fp, 1):
-            items.append(read_fmt('B', fp)[0])
+            items.append(read_fmt("B", fp)[0])
         return cls(items)
 
     def write(self, fp, **kwargs):
-        return sum(write_fmt(fp, 'B', item) for item in self)
+        return sum(write_fmt(fp, "B", item) for item in self)
 
 
 @register(Resource.LAYER_GROUP_INFO)
@@ -472,11 +489,11 @@ class LayerGroupInfo(ListElement):
     def read(cls, fp, **kwargs):
         items = []
         while is_readable(fp, 2):
-            items.append(read_fmt('H', fp)[0])
+            items.append(read_fmt("H", fp)[0])
         return cls(items)
 
     def write(self, fp, **kwargs):
-        return sum(write_fmt(fp, 'H', item) for item in self)
+        return sum(write_fmt(fp, "H", item) for item in self)
 
 
 @register(Resource.LAYER_SELECTION_IDS)
@@ -487,12 +504,12 @@ class LayerSelectionIDs(ListElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        count = read_fmt('H', fp)[0]
-        return cls(read_fmt('I', fp)[0] for _ in range(count))
+        count = read_fmt("H", fp)[0]
+        return cls(read_fmt("I", fp)[0] for _ in range(count))
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, 'H', len(self))
-        written += sum(write_fmt(fp, 'I', item) for item in self)
+        written = write_fmt(fp, "H", len(self))
+        written += sum(write_fmt(fp, "I", item) for item in self)
         return written
 
 
@@ -506,10 +523,10 @@ class ShortInteger(ShortIntegerElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        return cls(*read_fmt('H', fp))
+        return cls(*read_fmt("H", fp))
 
     def write(self, fp, **kwargs):
-        return write_fmt(fp, 'H', self.value)
+        return write_fmt(fp, "H", self.value)
 
 
 @register(Resource.CAPTION_PASCAL)
@@ -521,10 +538,10 @@ class PascalString(ValueElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        return cls(read_pascal_string(fp, 'macroman'))
+        return cls(read_pascal_string(fp, "macroman"))
 
     def write(self, fp, **kwargs):
-        return write_pascal_string(fp, self.value, 'macroman', padding=1)
+        return write_pascal_string(fp, self.value, "macroman", padding=1)
 
 
 @register(Resource.PIXEL_ASPECT_RATIO)
@@ -535,15 +552,16 @@ class PixelAspectRatio(NumericElement):
 
     .. py:attribute: version
     """
+
     version = attr.ib(default=1, type=int)
 
     @classmethod
     def read(cls, fp, **kwargs):
-        version, value = read_fmt('Id', fp)
+        version, value = read_fmt("Id", fp)
         return cls(version=version, value=value)
 
     def write(self, fp, **kwargs):
-        return write_fmt(fp, 'Id', self.version, self.value)
+        return write_fmt(fp, "Id", self.version, self.value)
 
 
 @register(Resource.PRINT_FLAGS)
@@ -562,6 +580,7 @@ class PrintFlags(BaseElement):
     .. py:attribute: caption
     .. py:attribute: print_flags
     """
+
     labels = attr.ib(default=False, type=bool)
     crop_marks = attr.ib(default=False, type=bool)
     colorbars = attr.ib(default=False, type=bool)
@@ -574,16 +593,16 @@ class PrintFlags(BaseElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        values = read_fmt('8?', fp)
+        values = read_fmt("8?", fp)
         if is_readable(fp):
-            values += read_fmt('?', fp)
+            values += read_fmt("?", fp)
         return cls(*values)
 
     def write(self, fp, **kwargs):
         values = attr.astuple(self)
         if self.print_flags is None:
             values = values[:-1]
-        return write_fmt(fp, '%d?' % len(values), *values)
+        return write_fmt(fp, "%d?" % len(values), *values)
 
 
 @register(Resource.PRINT_FLAGS_INFO)
@@ -597,6 +616,7 @@ class PrintFlagsInfo(BaseElement):
     .. py:attribute:: bleed_width_value
     .. py:attribute:: bleed_width_scale
     """
+
     version = attr.ib(default=0, type=int)
     center_crop = attr.ib(default=0, type=int)
     bleed_width_value = attr.ib(default=0, type=int)
@@ -604,10 +624,10 @@ class PrintFlagsInfo(BaseElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        return cls(*read_fmt('HBxIH', fp))
+        return cls(*read_fmt("HBxIH", fp))
 
     def write(self, fp, **kwargs):
-        return write_fmt(fp, 'HBxIH', *attr.astuple(self))
+        return write_fmt(fp, "HBxIH", *attr.astuple(self))
 
 
 @register(Resource.PRINT_SCALE)
@@ -621,23 +641,22 @@ class PrintScale(BaseElement):
     .. py:attribute:: y
     .. py:attribute:: scale
     """
+
     style = attr.ib(
         default=PrintScaleStyle.CENTERED,
         converter=PrintScaleStyle,
-        validator=in_(PrintScaleStyle)
+        validator=in_(PrintScaleStyle),
     )
-    x = attr.ib(default=0., type=float)
-    y = attr.ib(default=0., type=float)
-    scale = attr.ib(default=0., type=float)
+    x = attr.ib(default=0.0, type=float)
+    y = attr.ib(default=0.0, type=float)
+    scale = attr.ib(default=0.0, type=float)
 
     @classmethod
     def read(cls, fp, **kwargs):
-        return cls(*read_fmt('H3f', fp))
+        return cls(*read_fmt("H3f", fp))
 
     def write(self, fp, **kwargs):
-        return write_fmt(
-            fp, 'H3f', self.style.value, self.x, self.y, self.scale
-        )
+        return write_fmt(fp, "H3f", self.style.value, self.x, self.y, self.scale)
 
 
 @register(Resource.RESOLUTION_INFO)
@@ -653,6 +672,7 @@ class ResoulutionInfo(BaseElement):
     .. py:attribute:: vertical_unit
     .. py:attribute:: height_unit
     """
+
     horizontal = attr.ib(default=0, type=int)
     horizontal_unit = attr.ib(default=0, type=int)
     width_unit = attr.ib(default=0, type=int)
@@ -662,10 +682,10 @@ class ResoulutionInfo(BaseElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        return cls(*read_fmt('I2HI2H', fp))
+        return cls(*read_fmt("I2HI2H", fp))
 
     def write(self, fp, **kwargs):
-        return write_fmt(fp, 'I2HI2H', *attr.astuple(self))
+        return write_fmt(fp, "I2HI2H", *attr.astuple(self))
 
 
 @register(Resource.SLICES)
@@ -677,19 +697,20 @@ class Slices(BaseElement):
     .. py:attribute:: version
     .. py:attribute:: data
     """
+
     version = attr.ib(default=0, type=int, validator=in_((6, 7, 8)))
     data = attr.ib(default=None)
 
     @classmethod
     def read(cls, fp, **kwargs):
-        version = read_fmt('I', fp)[0]
-        assert version in (6, 7, 8), 'Invalid version %d' % (version)
+        version = read_fmt("I", fp)[0]
+        assert version in (6, 7, 8), "Invalid version %d" % (version)
         if version == 6:
             return cls(version=version, data=SlicesV6.read(fp))
         return cls(version=version, data=DescriptorBlock.read(fp))
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, 'I', self.version)
+        written = write_fmt(fp, "I", self.version)
         written += self.data.write(fp, padding=1)
         return written
 
@@ -703,22 +724,23 @@ class SlicesV6(BaseElement):
     .. py:attribute:: name
     .. py:attribute:: items
     """
+
     bbox = attr.ib(factory=lambda: [0, 0, 0, 0], converter=list)
-    name = attr.ib(default='', type=str)
+    name = attr.ib(default="", type=str)
     items = attr.ib(factory=list, converter=list)
 
     @classmethod
     def read(cls, fp):
-        bbox = read_fmt('4I', fp)
+        bbox = read_fmt("4I", fp)
         name = read_unicode_string(fp)
-        count = read_fmt('I', fp)[0]
+        count = read_fmt("I", fp)[0]
         items = [SliceV6.read(fp) for _ in range(count)]
         return cls(bbox, name, items)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, '4I', *self.bbox)
+        written = write_fmt(fp, "4I", *self.bbox)
         written += write_unicode_string(fp, self.name)
-        written += write_fmt(fp, 'I', len(self.items))
+        written += write_fmt(fp, "I", len(self.items))
         written += sum(item.write(fp) for item in self.items)
         return written
 
@@ -749,19 +771,20 @@ class SliceV6(BaseElement):
     .. py:attribute:: blue
     .. py:attribute:: data
     """
+
     slice_id = attr.ib(default=0, type=int)
     group_id = attr.ib(default=0, type=int)
     origin = attr.ib(default=0, type=int)
     associated_id = attr.ib(default=None)
-    name = attr.ib(default='', type=str)
+    name = attr.ib(default="", type=str)
     slice_type = attr.ib(default=0, type=int)
     bbox = attr.ib(factory=lambda: [0, 0, 0, 0], converter=list)
-    url = attr.ib(default='', type=str)
-    target = attr.ib(default='', type=str)
-    message = attr.ib(default='', type=str)
-    alt_tag = attr.ib(default='', type=str)
+    url = attr.ib(default="", type=str)
+    target = attr.ib(default="", type=str)
+    message = attr.ib(default="", type=str)
+    alt_tag = attr.ib(default="", type=str)
     cell_is_html = attr.ib(default=False, type=bool)
-    cell_text = attr.ib(default='', type=str)
+    cell_text = attr.ib(default="", type=str)
     horizontal_align = attr.ib(default=0, type=int)
     vertical_align = attr.ib(default=0, type=int)
     alpha = attr.ib(default=0, type=int)
@@ -772,64 +795,75 @@ class SliceV6(BaseElement):
 
     @classmethod
     def read(cls, fp):
-        slice_id, group_id, origin = read_fmt('3I', fp)
-        associated_id = read_fmt('I', fp)[0] if origin == 1 else None
+        slice_id, group_id, origin = read_fmt("3I", fp)
+        associated_id = read_fmt("I", fp)[0] if origin == 1 else None
         name = read_unicode_string(fp)
-        slice_type = read_fmt('I', fp)[0]
-        bbox = read_fmt('4I', fp)
+        slice_type = read_fmt("I", fp)[0]
+        bbox = read_fmt("4I", fp)
         url = read_unicode_string(fp)
         target = read_unicode_string(fp)
         message = read_unicode_string(fp)
         alt_tag = read_unicode_string(fp)
-        cell_is_html = read_fmt('?', fp)[0]
+        cell_is_html = read_fmt("?", fp)[0]
         cell_text = read_unicode_string(fp)
-        horizontal_align, vertical_align = read_fmt('2I', fp)
-        alpha, red, green, blue = read_fmt('4B', fp)
+        horizontal_align, vertical_align = read_fmt("2I", fp)
+        alpha, red, green, blue = read_fmt("4B", fp)
         data = None
         if is_readable(fp, 4):
             # There is no easy distinction between descriptor block and
             # next slice v6 item here...
             current_position = fp.tell()
-            version = read_fmt('I', fp)[0]
+            version = read_fmt("I", fp)[0]
             fp.seek(-4, 1)
             if version == 16:
                 try:
                     data = DescriptorBlock.read(fp)
-                    if data.classID == b'\x00\x00\x00\x00':
+                    if data.classID == b"\x00\x00\x00\x00":
                         data = None
                         raise ValueError(data)
                 except ValueError:
-                    logger.debug('Failed to read DescriptorBlock')
+                    logger.debug("Failed to read DescriptorBlock")
                     fp.seek(current_position)
         return cls(
-            slice_id, group_id, origin, associated_id, name, slice_type, bbox,
-            url, target, message, alt_tag, cell_is_html, cell_text,
-            horizontal_align, vertical_align, alpha, red, green, blue, data
+            slice_id,
+            group_id,
+            origin,
+            associated_id,
+            name,
+            slice_type,
+            bbox,
+            url,
+            target,
+            message,
+            alt_tag,
+            cell_is_html,
+            cell_text,
+            horizontal_align,
+            vertical_align,
+            alpha,
+            red,
+            green,
+            blue,
+            data,
         )
 
     def write(self, fp):
-        written = write_fmt(
-            fp, '3I', self.slice_id, self.group_id, self.origin
-        )
+        written = write_fmt(fp, "3I", self.slice_id, self.group_id, self.origin)
         if self.origin == 1 and self.associated_id is not None:
-            written += write_fmt(fp, 'I', self.associated_id)
+            written += write_fmt(fp, "I", self.associated_id)
         written += write_unicode_string(fp, self.name, padding=1)
-        written += write_fmt(fp, 'I', self.slice_type)
-        written += write_fmt(fp, '4I', *self.bbox)
+        written += write_fmt(fp, "I", self.slice_type)
+        written += write_fmt(fp, "4I", *self.bbox)
         written += write_unicode_string(fp, self.url, padding=1)
         written += write_unicode_string(fp, self.target, padding=1)
         written += write_unicode_string(fp, self.message, padding=1)
         written += write_unicode_string(fp, self.alt_tag, padding=1)
-        written += write_fmt(fp, '?', self.cell_is_html)
+        written += write_fmt(fp, "?", self.cell_is_html)
         written += write_unicode_string(fp, self.cell_text, padding=1)
-        written += write_fmt(
-            fp, '2I', self.horizontal_align, self.vertical_align
-        )
-        written += write_fmt(
-            fp, '4B', self.alpha, self.red, self.green, self.blue
-        )
+        written += write_fmt(fp, "2I", self.horizontal_align, self.vertical_align)
+        written += write_fmt(fp, "4B", self.alpha, self.red, self.green, self.blue)
         if self.data is not None:
-            if hasattr(self.data, 'write'):
+            if hasattr(self.data, "write"):
                 written += self.data.write(fp, padding=1)
             elif self.data:
                 written += write_bytes(fp, self.data)
@@ -852,7 +886,8 @@ class ThumbnailResource(BaseElement):
     .. py:attribute:: planes
     .. py:attribute:: data
     """
-    _RAW_MODE = 'RGB'
+
+    _RAW_MODE = "RGB"
 
     fmt = attr.ib(default=0, type=int)
     width = attr.ib(default=0, type=int)
@@ -861,20 +896,26 @@ class ThumbnailResource(BaseElement):
     total_size = attr.ib(default=0, type=int)
     bits = attr.ib(default=0, type=int)
     planes = attr.ib(default=0, type=int)
-    data = attr.ib(default=b'', type=bytes)
+    data = attr.ib(default=b"", type=bytes)
 
     @classmethod
     def read(cls, fp, **kwargs):
-        fmt, width, height, row, total_size, size, bits, planes = read_fmt(
-            '6I2H', fp
-        )
+        fmt, width, height, row, total_size, size, bits, planes = read_fmt("6I2H", fp)
         data = fp.read(size)
         return cls(fmt, width, height, row, total_size, bits, planes, data)
 
     def write(self, fp, **kwargs):
         written = write_fmt(
-            fp, '6I2H', self.fmt, self.width, self.height, self.row,
-            self.total_size, len(self.data), self.bits, self.planes
+            fp,
+            "6I2H",
+            self.fmt,
+            self.width,
+            self.height,
+            self.row,
+            self.total_size,
+            len(self.data),
+            self.bits,
+            self.planes,
         )
         written += write_bytes(fp, self.data)
         return written
@@ -886,21 +927,26 @@ class ThumbnailResource(BaseElement):
         :return: PIL Image object.
         """
         from PIL import Image
+
         if self.fmt == 1:
             with io.BytesIO(self.data) as f:
                 image = Image.open(f)
                 image.load()
         else:
             image = Image.frombytes(
-                'RGB', (self.width, self.height), self.data, 'raw',
-                self._RAW_MODE, self.row
+                "RGB",
+                (self.width, self.height),
+                self.data,
+                "raw",
+                self._RAW_MODE,
+                self.row,
             )
         return image
 
 
 @register(Resource.THUMBNAIL_RESOURCE_PS4)
 class ThumbnailResourceV4(ThumbnailResource):
-    _RAW_MODE = 'BGR'
+    _RAW_MODE = "BGR"
 
 
 @register(Resource.COLOR_TRANSFER_FUNCTION)
@@ -927,18 +973,19 @@ class TransferFunction(BaseElement):
     """
     Transfer function
     """
+
     curve = attr.ib(factory=list, converter=list)
     override = attr.ib(default=False, type=bool)
 
     @classmethod
     def read(cls, fp, **kwargs):
-        curve = read_fmt('13H', fp)
-        override = read_fmt('H', fp)[0]
+        curve = read_fmt("13H", fp)
+        override = read_fmt("H", fp)[0]
         return cls(curve, override)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, '13H', *self.curve)
-        written += write_fmt(fp, 'H', self.override)
+        written = write_fmt(fp, "13H", *self.curve)
+        written += write_fmt(fp, "H", self.override)
         return written
 
 
@@ -950,14 +997,14 @@ class URLList(ListElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        count = read_fmt('I', fp)[0]
+        count = read_fmt("I", fp)[0]
         items = []
         for _ in range(count):
             items.append(URLItem.read(fp))
         return cls(items)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, 'I', len(self))
+        written = write_fmt(fp, "I", len(self))
         written += sum(item.write(fp) for item in self)
         return written
 
@@ -971,18 +1018,19 @@ class URLItem(BaseElement):
     .. py:attribute:: id
     .. py:attribute:: name
     """
+
     number = attr.ib(default=0, type=int)
     id = attr.ib(default=0, type=int)
-    name = attr.ib(default='', type=str)
+    name = attr.ib(default="", type=str)
 
     @classmethod
     def read(cls, fp):
-        number, id = read_fmt('2I', fp)
+        number, id = read_fmt("2I", fp)
         name = read_unicode_string(fp)
         return cls(number, id, name)
 
     def write(self, fp):
-        written = write_fmt(fp, '2I', self.number, self.id)
+        written = write_fmt(fp, "2I", self.number, self.id)
         written += write_unicode_string(fp, self.name)
         return written
 
@@ -999,23 +1047,24 @@ class VersionInfo(BaseElement):
     .. py:attribute:: reader
     .. py:attribute:: file_version
     """
+
     version = attr.ib(default=1, type=int)
     has_composite = attr.ib(default=False, type=bool)
-    writer = attr.ib(default='', type=str)
-    reader = attr.ib(default='', type=str)
+    writer = attr.ib(default="", type=str)
+    reader = attr.ib(default="", type=str)
     file_version = attr.ib(default=1, type=int)
 
     @classmethod
     def read(cls, fp, **kwargs):
-        version, has_composite = read_fmt('I?', fp)
+        version, has_composite = read_fmt("I?", fp)
         writer = read_unicode_string(fp)
         reader = read_unicode_string(fp)
-        file_version = read_fmt('I', fp)[0]
+        file_version = read_fmt("I", fp)[0]
         return cls(version, has_composite, writer, reader, file_version)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, 'I?', self.version, self.has_composite)
+        written = write_fmt(fp, "I?", self.version, self.has_composite)
         written += write_unicode_string(fp, self.writer)
         written += write_unicode_string(fp, self.reader)
-        written += write_fmt(fp, 'I', self.file_version)
+        written += write_fmt(fp, "I", self.file_version)
         return written
