@@ -2,22 +2,35 @@
 Layer and mask data structure.
 """
 from __future__ import absolute_import, unicode_literals
-import attr
+
 import io
 import logging
 
+import attr
+
+from psd_tools.compression import compress, decompress
+from psd_tools.constants import (
+    BlendMode,
+    ChannelID,
+    Clipping,
+    Compression,
+    GlobalLayerMaskKind,
+    Tag,
+)
 from psd_tools.psd.base import BaseElement, ListElement
 from psd_tools.psd.tagged_blocks import TaggedBlocks, register
-from psd_tools.compression import compress, decompress
-from psd_tools.validators import in_, range_
-from psd_tools.constants import (
-    BlendMode, Clipping, Compression, ChannelID, GlobalLayerMaskKind, Tag
-)
 from psd_tools.utils import (
-    read_fmt, write_fmt, read_pascal_string, write_pascal_string,
-    read_length_block, write_length_block, is_readable, write_padding,
-    write_bytes
+    is_readable,
+    read_fmt,
+    read_length_block,
+    read_pascal_string,
+    write_bytes,
+    write_fmt,
+    write_length_block,
+    write_padding,
+    write_pascal_string,
 )
+from psd_tools.validators import in_, range_
 
 logger = logging.getLogger(__name__)
 
@@ -39,18 +52,18 @@ class LayerAndMaskInformation(BaseElement):
 
         See :py:class:`.TaggedBlocks`.
     """
+
     layer_info = attr.ib(default=None)
     global_layer_mask_info = attr.ib(default=None)
     tagged_blocks = attr.ib(default=None)
 
     @classmethod
-    def read(cls, fp, encoding='macroman', version=1):
+    def read(cls, fp, encoding="macroman", version=1):
         start_pos = fp.tell()
-        length = read_fmt(('I', 'Q')[version - 1], fp)[0]
+        length = read_fmt(("I", "Q")[version - 1], fp)[0]
         end_pos = fp.tell() + length
         logger.debug(
-            'reading layer and mask info, len=%d, offset=%d' %
-            (length, start_pos)
+            "reading layer and mask info, len=%d, offset=%d" % (length, start_pos)
         )
         if length == 0:
             self = cls()
@@ -58,8 +71,9 @@ class LayerAndMaskInformation(BaseElement):
             self = cls._read_body(fp, end_pos, encoding, version)
         if fp.tell() > end_pos:
             logger.warning(
-                'LayerAndMaskInformation is broken: current fp=%d, expected=%d' % (
-                    fp.tell(), end_pos))
+                "LayerAndMaskInformation is broken: current fp=%d, expected=%d"
+                % (fp.tell(), end_pos)
+            )
         fp.seek(end_pos, 0)
         return self
 
@@ -80,13 +94,13 @@ class LayerAndMaskInformation(BaseElement):
 
         return cls(layer_info, global_layer_mask_info, tagged_blocks)
 
-    def write(self, fp, encoding='macroman', version=1, padding=4):
+    def write(self, fp, encoding="macroman", version=1, padding=4):
         def writer(f):
             written = self._write_body(f, encoding, version, padding)
-            logger.debug('writing layer and mask info, len=%d' % (written))
+            logger.debug("writing layer and mask info, len=%d" % (written))
             return written
 
-        fmt = ('I', 'Q')[version - 1]
+        fmt = ("I", "Q")[version - 1]
         return write_length_block(fp, writer, fmt=fmt)
 
     def _write_body(self, fp, encoding, version, padding):
@@ -119,14 +133,15 @@ class LayerInfo(BaseElement):
 
         Channel image data. See :py:class:`.ChannelImageData`.
     """
+
     layer_count = attr.ib(default=0, type=int)
     layer_records = attr.ib(default=None)
     channel_image_data = attr.ib(default=None)
 
     @classmethod
-    def read(cls, fp, encoding='macroman', version=1):
-        length = read_fmt(('I', 'Q')[version - 1], fp)[0]
-        logger.debug('reading layer info, len=%d' % length)
+    def read(cls, fp, encoding="macroman", version=1):
+        length = read_fmt(("I", "Q")[version - 1], fp)[0]
+        logger.debug("reading layer info, len=%d" % length)
         end_pos = fp.tell() + length
         if length == 0:
             self = LayerInfo()
@@ -139,30 +154,30 @@ class LayerInfo(BaseElement):
     @classmethod
     def _read_body(cls, fp, encoding, version):
         start_pos = fp.tell()
-        layer_count = read_fmt('h', fp)[0]
+        layer_count = read_fmt("h", fp)[0]
         layer_records = LayerRecords.read(fp, layer_count, encoding, version)
-        logger.debug('  read layer records, len=%d' % (fp.tell() - start_pos))
+        logger.debug("  read layer records, len=%d" % (fp.tell() - start_pos))
         channel_image_data = ChannelImageData.read(fp, layer_records)
         return cls(layer_count, layer_records, channel_image_data)
 
-    def write(self, fp, encoding='macroman', version=1, padding=4):
+    def write(self, fp, encoding="macroman", version=1, padding=4):
         def writer(f):
             written = self._write_body(f, encoding, version, padding)
-            logger.debug('writing layer info, len=%d' % (written))
+            logger.debug("writing layer info, len=%d" % (written))
             return written
 
-        fmt = ('I', 'Q')[version - 1]
+        fmt = ("I", "Q")[version - 1]
         if self.layer_count == 0:
             return write_fmt(fp, fmt, 0)
         return write_length_block(fp, writer, fmt=fmt)
 
     def _write_body(self, fp, encoding, version, padding):
         start_pos = fp.tell()
-        written = write_fmt(fp, 'h', self.layer_count)
+        written = write_fmt(fp, "h", self.layer_count)
         if self.layer_records:
             self._update_channel_length()
             written += self.layer_records.write(fp, encoding, version)
-        logger.debug('  wrote layer records, len=%d' % (fp.tell() - start_pos))
+        logger.debug("  wrote layer records, len=%d" % (fp.tell() - start_pos))
         if self.channel_image_data:
             written += self.channel_image_data.write(fp)
         # Seems the padding size here is different between Photoshop and GIMP.
@@ -173,9 +188,7 @@ class LayerInfo(BaseElement):
         if not self.layer_records or not self.channel_image_data:
             return
 
-        for layer, lengths in zip(
-            self.layer_records, self.channel_image_data._lengths
-        ):
+        for layer, lengths in zip(self.layer_records, self.channel_image_data._lengths):
             for channel_info, length in zip(layer.channel_info, lengths):
                 channel_info.length = length
 
@@ -184,14 +197,13 @@ class LayerInfo(BaseElement):
 @register(Tag.LAYER_32)
 @attr.s(repr=False)
 class LayerInfoBlock(LayerInfo):
-    """
-    """
+    """ """
 
     @classmethod
-    def read(cls, fp, encoding='macroman', version=1, **kwargs):
+    def read(cls, fp, encoding="macroman", version=1, **kwargs):
         return cls._read_body(fp, encoding, version)
 
-    def write(self, fp, encoding='macroman', version=1, padding=4, **kwargs):
+    def write(self, fp, encoding="macroman", version=1, padding=4, **kwargs):
         return self._write_body(fp, encoding, version, padding)
 
 
@@ -211,19 +223,18 @@ class ChannelInfo(BaseElement):
 
         Length of the corresponding channel data.
     """
+
     id = attr.ib(
-        default=ChannelID.CHANNEL_0,
-        converter=ChannelID,
-        validator=in_(ChannelID)
+        default=ChannelID.CHANNEL_0, converter=ChannelID, validator=in_(ChannelID)
     )
     length = attr.ib(default=0, type=int)
 
     @classmethod
     def read(cls, fp, version=1):
-        return cls(*read_fmt(('hI', 'hQ')[version - 1], fp))
+        return cls(*read_fmt(("hI", "hQ")[version - 1], fp))
 
     def write(self, fp, version=1):
-        return write_fmt(fp, ('hI', 'hQ')[version - 1], *attr.astuple(self))
+        return write_fmt(fp, ("hI", "hQ")[version - 1], *attr.astuple(self))
 
 
 @attr.s(repr=False, slots=True)
@@ -237,6 +248,7 @@ class LayerFlags(BaseElement):
     .. py:attribute:: visible
     .. py:attribute:: pixel_data_irrelevant
     """
+
     transparency_protected = attr.ib(default=False, type=bool)
     visible = attr.ib(default=True, type=bool)
     obsolete = attr.ib(default=False, type=bool, repr=False)
@@ -248,7 +260,7 @@ class LayerFlags(BaseElement):
 
     @classmethod
     def read(cls, fp):
-        flags = read_fmt('B', fp)[0]
+        flags = read_fmt("B", fp)[0]
         return cls(
             bool(flags & 1),
             not bool(flags & 2),  # why "not"?
@@ -257,16 +269,21 @@ class LayerFlags(BaseElement):
             bool(flags & 16),
             bool(flags & 32),
             bool(flags & 64),
-            bool(flags & 128)
+            bool(flags & 128),
         )
 
     def write(self, fp):
-        flags = ((self.transparency_protected * 1) | ((not self.visible) * 2) |
-                 (self.obsolete * 4) | (self.photoshop_v5_later * 8) |
-                 (self.pixel_data_irrelevant * 16) |
-                 (self.undocumented_1 * 32)
-                 | (self.undocumented_2 * 64) | (self.undocumented_3 * 128))
-        return write_fmt(fp, 'B', flags)
+        flags = (
+            (self.transparency_protected * 1)
+            | ((not self.visible) * 2)
+            | (self.obsolete * 4)
+            | (self.photoshop_v5_later * 8)
+            | (self.pixel_data_irrelevant * 16)
+            | (self.undocumented_1 * 32)
+            | (self.undocumented_2 * 64)
+            | (self.undocumented_3 * 128)
+        )
+        return write_fmt(fp, "B", flags)
 
 
 @attr.s(repr=False, slots=True)
@@ -284,7 +301,10 @@ class LayerBlendingRanges(BaseElement):
 
         List of channel source and destination ranges.
     """
-    composite_ranges = attr.ib(factory=lambda: [(0, 65535), (0, 65535)], )
+
+    composite_ranges = attr.ib(
+        factory=lambda: [(0, 65535), (0, 65535)],
+    )
     channel_ranges = attr.ib(
         factory=lambda: [
             [(0, 65535), (0, 65535)],
@@ -322,11 +342,11 @@ class LayerBlendingRanges(BaseElement):
         written = 0
         if self.composite_ranges is not None:
             for x in self.composite_ranges:
-                written += write_fmt(fp, '2H', *x)
+                written += write_fmt(fp, "2H", *x)
         if self.channel_ranges is not None:
             for channel in self.channel_ranges:
                 for x in channel:
-                    written += write_fmt(fp, '2H', *x)
+                    written += write_fmt(fp, "2H", *x)
         return written
 
 
@@ -336,9 +356,9 @@ class LayerRecords(ListElement):
     """
 
     @classmethod
-    def read(cls, fp, layer_count, encoding='macroman', version=1):
+    def read(cls, fp, layer_count, encoding="macroman", version=1):
         items = []
-        for idx in range(abs(layer_count)):
+        for _ in range(abs(layer_count)):
             items.append(LayerRecord.read(fp, encoding, version))
         return cls(items)
 
@@ -405,18 +425,17 @@ class LayerRecord(BaseElement):
 
         See :py:class:`.TaggedBlocks`.
     """
+
     top = attr.ib(default=0, type=int)
     left = attr.ib(default=0, type=int)
     bottom = attr.ib(default=0, type=int)
     right = attr.ib(default=0, type=int)
     channel_info = attr.ib(factory=list)
     signature = attr.ib(
-        default=b'8BIM', repr=False, type=bytes, validator=in_((b'8BIM', ))
+        default=b"8BIM", repr=False, type=bytes, validator=in_((b"8BIM",))
     )
     blend_mode = attr.ib(
-        default=BlendMode.NORMAL,
-        converter=BlendMode,
-        validator=in_(BlendMode)
+        default=BlendMode.NORMAL, converter=BlendMode, validator=in_(BlendMode)
     )
     opacity = attr.ib(default=255, type=int, validator=range_(0, 255))
     clipping = attr.ib(
@@ -425,26 +444,32 @@ class LayerRecord(BaseElement):
     flags = attr.ib(factory=LayerFlags)
     mask_data = attr.ib(default=None)
     blending_ranges = attr.ib(factory=LayerBlendingRanges)
-    name = attr.ib(default='', type=str)
+    name = attr.ib(default="", type=str)
     tagged_blocks = attr.ib(factory=TaggedBlocks)
 
     @classmethod
-    def read(cls, fp, encoding='macroman', version=1):
+    def read(cls, fp, encoding="macroman", version=1):
         start_pos = fp.tell()
-        top, left, bottom, right, num_channels = read_fmt('4iH', fp)
-        channel_info = [
-            ChannelInfo.read(fp, version) for i in range(num_channels)
-        ]
-        signature, blend_mode, opacity, clipping = read_fmt('4s4sBB', fp)
+        top, left, bottom, right, num_channels = read_fmt("4iH", fp)
+        channel_info = [ChannelInfo.read(fp, version) for i in range(num_channels)]
+        signature, blend_mode, opacity, clipping = read_fmt("4s4sBB", fp)
         flags = LayerFlags.read(fp)
 
-        data = read_length_block(fp, fmt='xI')
-        logger.debug('  read layer record, len=%d' % (fp.tell() - start_pos))
+        data = read_length_block(fp, fmt="xI")
+        logger.debug("  read layer record, len=%d" % (fp.tell() - start_pos))
         with io.BytesIO(data) as f:
             self = cls(
-                top, left, bottom, right, channel_info, signature,
-                blend_mode, opacity, clipping, flags,
-                *cls._read_extra(f, encoding, version)
+                top,
+                left,
+                bottom,
+                right,
+                channel_info,
+                signature,
+                blend_mode,
+                opacity,
+                clipping,
+                flags,
+                *cls._read_extra(f, encoding, version),
             )
 
         # with io.BytesIO() as f:
@@ -461,27 +486,34 @@ class LayerRecord(BaseElement):
         tagged_blocks = TaggedBlocks.read(fp, version=version, padding=1)
         return mask_data, blending_ranges, name, tagged_blocks
 
-    def write(self, fp, encoding='macroman', version=1):
+    def write(self, fp, encoding="macroman", version=1):
         start_pos = fp.tell()
         written = write_fmt(
-            fp, '4iH', self.top, self.left, self.bottom, self.right,
-            len(self.channel_info)
+            fp,
+            "4iH",
+            self.top,
+            self.left,
+            self.bottom,
+            self.right,
+            len(self.channel_info),
         )
         written += sum(c.write(fp, version) for c in self.channel_info)
         written += write_fmt(
-            fp, '4s4sBB', self.signature, self.blend_mode.value, self.opacity,
-            self.clipping.value
+            fp,
+            "4s4sBB",
+            self.signature,
+            self.blend_mode.value,
+            self.opacity,
+            self.clipping.value,
         )
         written += self.flags.write(fp)
 
         def writer(f):
             written = self._write_extra(f, encoding, version)
-            logger.debug(
-                '  wrote layer record, len=%d' % (fp.tell() - start_pos)
-            )
+            logger.debug("  wrote layer record, len=%d" % (fp.tell() - start_pos))
             return written
 
-        written += write_length_block(fp, writer, fmt='xI')
+        written += write_length_block(fp, writer, fmt="xI")
         return written
 
     def _write_extra(self, fp, encoding, version):
@@ -489,7 +521,7 @@ class LayerRecord(BaseElement):
         if self.mask_data:
             written += self.mask_data.write(fp)
         else:
-            written += write_fmt(fp, 'I', 0)
+            written += write_fmt(fp, "I", 0)
 
         written += self.blending_ranges.write(fp)
         written += write_pascal_string(fp, self.name, encoding, padding=4)
@@ -509,16 +541,13 @@ class LayerRecord(BaseElement):
 
     @property
     def channel_sizes(self):
-        """List of channel sizes: [(width, height)].
-        """
+        """List of channel sizes: [(width, height)]."""
         sizes = []
         for channel in self.channel_info:
             if channel.id == ChannelID.USER_LAYER_MASK:
                 sizes.append((self.mask_data.width, self.mask_data.height))
             elif channel.id == ChannelID.REAL_USER_LAYER_MASK:
-                sizes.append(
-                    (self.mask_data.real_width, self.mask_data.real_height)
-                )
+                sizes.append((self.mask_data.real_width, self.mask_data.real_height))
             else:
                 sizes.append((self.width, self.height))
         return sizes
@@ -549,6 +578,7 @@ class MaskFlags(BaseElement):
 
         The user and/or vector masks have parameters applied to them.
     """
+
     pos_relative_to_layer = attr.ib(default=False, type=bool)
     mask_disabled = attr.ib(default=False, type=bool)
     invert_mask = attr.ib(default=False, type=bool)
@@ -560,19 +590,30 @@ class MaskFlags(BaseElement):
 
     @classmethod
     def read(cls, fp):
-        flags = read_fmt('B', fp)[0]
+        flags = read_fmt("B", fp)[0]
         return cls(
-            bool(flags & 1), bool(flags & 2), bool(flags & 4), bool(flags & 8),
-            bool(flags & 16), bool(flags & 32), bool(flags & 64),
-            bool(flags & 128)
+            bool(flags & 1),
+            bool(flags & 2),
+            bool(flags & 4),
+            bool(flags & 8),
+            bool(flags & 16),
+            bool(flags & 32),
+            bool(flags & 64),
+            bool(flags & 128),
         )
 
     def write(self, fp):
-        flags = ((self.pos_relative_to_layer * 1) | (self.mask_disabled * 2) |
-                 (self.invert_mask * 4) | (self.user_mask_from_render * 8) |
-                 (self.parameters_applied * 16) | (self.undocumented_1 * 32) |
-                 (self.undocumented_2 * 64) | (self.undocumented_3 * 128))
-        return write_fmt(fp, 'B', flags)
+        flags = (
+            (self.pos_relative_to_layer * 1)
+            | (self.mask_disabled * 2)
+            | (self.invert_mask * 4)
+            | (self.user_mask_from_render * 8)
+            | (self.parameters_applied * 16)
+            | (self.undocumented_1 * 32)
+            | (self.undocumented_2 * 64)
+            | (self.undocumented_3 * 128)
+        )
+        return write_fmt(fp, "B", flags)
 
 
 @attr.s(repr=False, slots=True)
@@ -634,6 +675,7 @@ class MaskData(BaseElement):
 
         Right position of real user mask.
     """
+
     top = attr.ib(default=0, type=int)
     left = attr.ib(default=0, type=int)
     bottom = attr.ib(default=0, type=int)
@@ -659,7 +701,7 @@ class MaskData(BaseElement):
 
     @classmethod
     def _read_body(cls, fp, length):
-        top, left, bottom, right, background_color = read_fmt('4iB', fp)
+        top, left, bottom, right, background_color = read_fmt("4iB", fp)
         flags = MaskFlags.read(fp)
 
         # Order is based on tests. The specification is messed up here...
@@ -672,8 +714,8 @@ class MaskData(BaseElement):
         real_top, real_left, real_bottom, real_right = None, None, None, None
         if length >= 36:
             real_flags = MaskFlags.read(fp)
-            real_background_color = read_fmt('B', fp)[0]
-            real_top, real_left, real_bottom, real_right = read_fmt('4i', fp)
+            real_background_color = read_fmt("B", fp)[0]
+            real_top, real_left, real_bottom, real_right = read_fmt("4i", fp)
 
         parameters = None
         if flags.parameters_applied:
@@ -681,9 +723,19 @@ class MaskData(BaseElement):
 
         # logger.debug('    skipping %d' % (len(fp.read())))
         return cls(
-            top, left, bottom, right, background_color, flags, parameters,
-            real_flags, real_background_color, real_top, real_left,
-            real_bottom, real_right
+            top,
+            left,
+            bottom,
+            right,
+            background_color,
+            flags,
+            parameters,
+            real_flags,
+            real_background_color,
+            real_top,
+            real_left,
+            real_bottom,
+            real_right,
         )
 
     def write(self, fp):
@@ -691,8 +743,13 @@ class MaskData(BaseElement):
 
     def _write_body(self, fp):
         written = write_fmt(
-            fp, '4iB', self.top, self.left, self.bottom, self.right,
-            self.background_color
+            fp,
+            "4iB",
+            self.top,
+            self.left,
+            self.bottom,
+            self.right,
+            self.background_color,
         )
         written += self.flags.write(fp)
 
@@ -703,8 +760,13 @@ class MaskData(BaseElement):
         if self.real_flags:
             written += self.real_flags.write(fp)
             written += write_fmt(
-                fp, 'B4i', self.real_background_color, self.real_top,
-                self.real_left, self.real_bottom, self.real_right
+                fp,
+                "B4i",
+                self.real_background_color,
+                self.real_top,
+                self.real_left,
+                self.real_bottom,
+                self.real_right,
             )
 
         if self.flags.parameters_applied and self.parameters:
@@ -744,6 +806,7 @@ class MaskParameters(BaseElement):
     .. py:attribute:: vector_mask_density
     .. py:attribute:: vector_mask_feather
     """
+
     user_mask_density = attr.ib(default=None)
     user_mask_feather = attr.ib(default=None)
     vector_mask_density = attr.ib(default=None)
@@ -751,30 +814,34 @@ class MaskParameters(BaseElement):
 
     @classmethod
     def read(cls, fp):
-        parameters = read_fmt('B', fp)[0]
+        parameters = read_fmt("B", fp)[0]
         return cls(
-            read_fmt('B', fp)[0] if bool(parameters & 1) else None,
-            read_fmt('d', fp)[0] if bool(parameters & 2) else None,
-            read_fmt('B', fp)[0] if bool(parameters & 4) else None,
-            read_fmt('d', fp)[0] if bool(parameters & 8) else None
+            read_fmt("B", fp)[0] if bool(parameters & 1) else None,
+            read_fmt("d", fp)[0] if bool(parameters & 2) else None,
+            read_fmt("B", fp)[0] if bool(parameters & 4) else None,
+            read_fmt("d", fp)[0] if bool(parameters & 8) else None,
         )
 
     def write(self, fp):
         written = 0
         written += write_fmt(
-            fp, 'B', ((1 if self.user_mask_density is not None else 0) |
-                      (2 if self.user_mask_feather is not None else 0) |
-                      (4 if self.vector_mask_density is not None else 0) |
-                      (8 if self.vector_mask_feather is not None else 0))
+            fp,
+            "B",
+            (
+                (1 if self.user_mask_density is not None else 0)
+                | (2 if self.user_mask_feather is not None else 0)
+                | (4 if self.vector_mask_density is not None else 0)
+                | (8 if self.vector_mask_feather is not None else 0)
+            ),
         )
         if self.user_mask_density is not None:
-            written += write_fmt(fp, 'B', self.user_mask_density)
+            written += write_fmt(fp, "B", self.user_mask_density)
         if self.user_mask_feather is not None:
-            written += write_fmt(fp, 'd', self.user_mask_feather)
+            written += write_fmt(fp, "d", self.user_mask_feather)
         if self.vector_mask_density is not None:
-            written += write_fmt(fp, 'B', self.vector_mask_density)
+            written += write_fmt(fp, "B", self.vector_mask_density)
         if self.vector_mask_feather is not None:
-            written += write_fmt(fp, 'd', self.vector_mask_feather)
+            written += write_fmt(fp, "d", self.vector_mask_feather)
         return written
 
 
@@ -793,25 +860,20 @@ class ChannelImageData(ListElement):
     def read(cls, fp, layer_records=None):
         start_pos = fp.tell()
         items = []
-        for idx, layer in enumerate(layer_records):
+        for layer in layer_records:
             items.append(ChannelDataList.read(fp, layer.channel_info))
-        logger.debug(
-            '  read channel image data, len=%d' % (fp.tell() - start_pos)
-        )
+        logger.debug("  read channel image data, len=%d" % (fp.tell() - start_pos))
         return cls(items)
 
     def write(self, fp, **kwargs):
         start_pos = fp.tell()
         written = sum(item.write(fp) for item in self)
-        logger.debug(
-            '  wrote channel image data, len=%d' % (fp.tell() - start_pos)
-        )
+        logger.debug("  wrote channel image data, len=%d" % (fp.tell() - start_pos))
         return written
 
     @property
     def _lengths(self):
-        """List of layer channel lengths.
-        """
+        """List of layer channel lengths."""
         return [item._lengths for item in self]
 
 
@@ -848,21 +910,20 @@ class ChannelData(BaseElement):
 
         Data.
     """
+
     compression = attr.ib(
-        default=Compression.RAW,
-        converter=Compression,
-        validator=in_(Compression)
+        default=Compression.RAW, converter=Compression, validator=in_(Compression)
     )
-    data = attr.ib(default=b'', type=bytes)
+    data = attr.ib(default=b"", type=bytes)
 
     @classmethod
     def read(cls, fp, length=0, **kwargs):
-        compression = Compression(read_fmt('H', fp)[0])
+        compression = Compression(read_fmt("H", fp)[0])
         data = fp.read(length)
         return cls(compression, data)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, 'H', self.compression.value)
+        written = write_fmt(fp, "H", self.compression.value)
         written += write_bytes(fp, self.data)
         # written += write_padding(fp, written, 2)  # Seems no padding here.
         return written
@@ -876,9 +937,7 @@ class ChannelData(BaseElement):
         :param version: psd file version.
         :rtype: bytes
         """
-        return decompress(
-            self.data, self.compression, width, height, depth, version
-        )
+        return decompress(self.data, self.compression, width, height, depth, version)
 
     def set_data(self, data, width, height, depth, version=1):
         """Set raw channel data and compress to store.
@@ -891,15 +950,12 @@ class ChannelData(BaseElement):
         :param depth: bit depth of the pixel.
         :param version: psd file version.
         """
-        self.data = compress(
-            data, self.compression, width, height, depth, version
-        )
+        self.data = compress(data, self.compression, width, height, depth, version)
         return len(self.data)
 
     @property
     def _length(self):
-        """Length of channel data block.
-        """
+        """Length of channel data block."""
         return 2 + len(self.data)
 
 
@@ -924,25 +980,26 @@ class GlobalLayerMaskInfo(BaseElement):
         128 = use value stored per layer. This value is preferred. The others
         are for backward compatibility with beta versions.
     """
+
     overlay_color = attr.ib(default=None)
     opacity = attr.ib(default=0, type=int)
     kind = attr.ib(
         default=GlobalLayerMaskKind.PER_LAYER,
         converter=GlobalLayerMaskKind,
-        validator=in_(GlobalLayerMaskKind)
+        validator=in_(GlobalLayerMaskKind),
     )
 
     @classmethod
     def read(cls, fp):
         pos = fp.tell()
         data = read_length_block(fp)  # fmt?
-        logger.debug('reading global layer mask info, len=%d' % (len(data)))
+        logger.debug("reading global layer mask info, len=%d" % (len(data)))
         if len(data) == 0:
             return cls(overlay_color=None)
         elif len(data) < 13:
             logger.warning(
-                'global layer mask info is broken, expected 13 bytes but found'
-                ' only %d' % (len(data))
+                "global layer mask info is broken, expected 13 bytes but found"
+                " only %d" % (len(data))
             )
             fp.seek(pos)
             return cls(overlay_color=None)
@@ -952,8 +1009,8 @@ class GlobalLayerMaskInfo(BaseElement):
 
     @classmethod
     def _read_body(cls, fp):
-        overlay_color = list(read_fmt('5H', fp))
-        opacity, kind = read_fmt('HB', fp)
+        overlay_color = list(read_fmt("5H", fp))
+        opacity, kind = read_fmt("HB", fp)
         return cls(overlay_color, opacity, kind)
 
     def write(self, fp):
@@ -962,8 +1019,8 @@ class GlobalLayerMaskInfo(BaseElement):
     def _write_body(self, fp):
         written = 0
         if self.overlay_color is not None:
-            written = write_fmt(fp, '5H', *self.overlay_color)
-            written += write_fmt(fp, 'HB', self.opacity, self.kind.value)
+            written = write_fmt(fp, "5H", *self.overlay_color)
+            written += write_fmt(fp, "HB", self.opacity, self.kind.value)
             written += write_padding(fp, written, 4)
-        logger.debug('writing global layer mask info, len=%d' % (written))
+        logger.debug("writing global layer mask info, len=%d" % (written))
         return written
